@@ -76,7 +76,7 @@ class MainWindow(QtGui.QMainWindow):
         
         #print"Debugger: \n\n"
         self.ui.showFullScreen()
-        self.ui.activate.hide()
+#        self.ui.activate.hide()
         self.ui.showbutton.hide()
         self.ui.search.clicked.connect(self.get_list)
         self.ui.activate.toggled.connect(self.set_as_default)
@@ -96,13 +96,15 @@ class MainWindow(QtGui.QMainWindow):
         try:
             os.makedirs("/home/user/MyDocs/.bfbc2stats/")
         except:
+#            print"folder exists"
             pass    
         
         #Üperprüfen, ob defaultplayer.txt vorhanden ist.Falls ja, Inhalt überprüfen.Wenn Inhalt leer, pass, wenn Inhalt vorhanden, laden
         if os.path.isfile("/home/user/MyDocs/.bfbc2stats/defaultplayer.ini"):
-           
+            
              
             if os.lstat("/home/user/MyDocs/.bfbc2stats/defaultplayer.ini").st_size > 0:
+                                
                 userdata={}
                 #try:
                 fobj=open("/home/user/MyDocs/.bfbc2stats/defaultplayer.ini","r")
@@ -111,18 +113,18 @@ class MainWindow(QtGui.QMainWindow):
                 for line in fobj:
                     zuordnung=line.split()
                     userdata[zuordnung[0]]=zuordnung[1]
-                    fobj.close  
+                fobj.close  
                 
                 setplayername=userdata["setplayername"]
                 setplatform=userdata["setplatform"]
                 index=userdata["index"]
                 self.ui.playername.setText(setplayername)
-                print"read from defaultplayer.ini"
+#                print"read from defaultplayer.ini"
                 self.ui.statsshow.clear()
                 self.ui.activate.setChecked(True)
                 self.get_stats_general(userdata)
                 try:
-                    print"read from bfbc2statscache.ini"
+#                    print"read from bfbc2statscache.ini"
                     #try:
                     fobj=open("/home/user/MyDocs/.bfbc2stats/bfbc2statscache.ini","r")
                     #except:    
@@ -131,7 +133,6 @@ class MainWindow(QtGui.QMainWindow):
                     self.ui.statsshow.setText(cachetext)
                     fobj.close()
                 except:
-                    print"except1"
                     pass    
                 
 
@@ -395,7 +396,7 @@ class MainWindow(QtGui.QMainWindow):
     def set_as_default(self):
         activatestate=self.ui.activate.checkState()
         if activatestate==False:
-            #print "Deaktivated"
+            print "Deaktivated"
             
             default=open("/home/user/MyDocs/.bfbc2stats/defaultplayer.ini","w")
                
@@ -415,7 +416,7 @@ class MainWindow(QtGui.QMainWindow):
             else:
                 #print"Userdatei schreiben"
                 #try:
-                default=open("/home/user/MyDocs/.bfbc2stats/bfbc2statsinformation.ini","w")
+                default=open("/home/user/MyDocs/.bfbc2stats/defaultplayer.ini","w")
                 #except:    
                     #default=open("defaultplayer.ini","w")
                
